<h1 align = "center">:rocket: 贝叶斯调参 :facepunch:</h1>

---
## 1. [Usages][1]
## 2. [Lgb-CV][2]
## 3. [Xgb-CV][3]
















---
[1]: http://nbviewer.jupyter.org/github/Jie-Yuan/DataMining/blob/master/8_ParametersTuning/BayesianOptimization/Usages.ipynb
[2]: https://github.com/Jie-Yuan/DataMining/blob/master/8_ParametersTuning/BayesianOptimization/lgb_cv.py
[3]: https://github.com/Jie-Yuan/DataMining/blob/master/8_ParametersTuning/BayesianOptimization/xgb_cv.py
